@@ -348,4 +348,7 @@ class HgImplementation(M.RepositoryImplementation):
             if os.path.exists(tmpfilename):
                 os.remove(tmpfilename)
 
+    def is_empty(self):
+        return self._hg.heads() == ['\x00'*20]
+
 Mapper.compile_all()
